# 元件指南 Brick Guides

本區彙整 llmbrick 各類元件（Brick）的詳細使用指南，包含設計理念、實作範例與最佳實踐。

```{toctree}
:maxdepth: 1
:caption: 元件指南

common_brick_guide
llm_brick_guide
compose_brick_guide
guard_brick_guide
intention_brick_guide
rectify_brick_guide
retrieval_brick_guide
translate_brick_guide
sse_server_guide
```

- 每份指南皆以步驟化、實作導向為主，適合開發者快速查閱與實作。